| shapiro_test | R Documentation |
Provides a pipe-friendly framework to performs Shapiro-Wilk test
of normality. Support grouped data and multiple variables for multivariate
normality tests. Wrapper around the R base function
shapiro.test(). Can handle grouped data.
See the Datanovia tutorial Normality Test in R for a worked walkthrough.
shapiro_test(data, ..., vars = NULL)
mshapiro_test(data)
data |
a data frame. Columns are variables. |
... |
One or more unquoted expressions (or variable names) separated by commas. Used to select a variable of interest. |
vars |
optional character vector containing variable names. Ignored when dot vars are specified. |
a data frame containing the value of the Shapiro-Wilk statistic and the corresponding p.value.
shapiro_test(): univariate Shapiro-Wilk normality test
mshapiro_test(): multivariate Shapiro-Wilk normality test. This is a
modified copy of the mshapiro.test() function of the package
mvnormtest, for internal convenience.
The Datanovia tutorial: Normality Test in R.
# Shapiro Wilk normality test for one variable
iris %>% shapiro_test(Sepal.Length)
# Shapiro Wilk normality test for two variables
iris %>% shapiro_test(Sepal.Length, Petal.Width)
# Multivariate normality test
mshapiro_test(iris[, 1:3])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.