powered by
Combines correlation coefficients and significance levels in a correlation matrix data.
See the Datanovia tutorial Correlation Matrix in R for a worked walkthrough.
cor_mark_significant( x, cutpoints = c(0, 1e-04, 0.001, 0.01, 0.05, 1), symbols = c("****", "***", "**", "*", "") )
a data frame containing the lower triangular part of the correlation matrix marked by significance symbols.
an object of class cor_mat().
cor_mat()
numeric vector used for intervals.
character vector, one shorter than cutpoints, used as significance symbols.
The Datanovia tutorial: Correlation Matrix in R.
mtcars %>% select(mpg, disp, hp, drat, wt, qsec) %>% cor_mat() %>% cor_mark_significant()
Run the code above in your browser using DataLab