| fligner_test | R Documentation |
Provides a pipe-friendly framework to perform the Fligner-Killeen
test, a non-parametric (rank-based) test of the homogeneity of group
variances. It is robust against departures from normality and is a useful
alternative to levene_test(). Wrapper around the function
fligner.test().
See the Datanovia tutorial Homogeneity of Variance Test in R for a worked walkthrough.
fligner_test(data, formula, ...)
data |
a data.frame containing the variables in the formula. |
formula |
a formula of the form |
... |
other arguments to be passed to the function
|
return a data frame with the following columns:
.y.: the y variable used in the test.
n: sample count.
statistic: the Fligner-Killeen test statistic (a chi-squared
statistic) used to compute the p-value.
df: the degrees of
freedom.
p: p-value.
method: the statistical test
used to compare groups.
levene_test
The Datanovia tutorial: Homogeneity of Variance Test in R.
# Load data
#:::::::::::::::::::::::::::::::::::::::
data("ToothGrowth")
df <- ToothGrowth
# Fligner-Killeen test
#:::::::::::::::::::::::::::::::::::::::::
df %>% fligner_test(len ~ dose)
# Grouped data
df %>%
group_by(supp) %>%
fligner_test(len ~ dose)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.