- data
a data.frame containing the variables in the formula.
- formula
a formula of the form x ~ group where x is a
numeric variable giving the data values and group is a factor with two
or more levels giving the corresponding groups.
- comparisons
A list of length-2 vectors specifying the groups of interest
to be compared. For example to compare groups "A" vs "B" and "B" vs "C", the
argument is as follow: comparisons = list(c("A", "B"), c("B", "C")).
- ref.group
a character string specifying the reference group. If
specified, for a given grouping variable, each of the group levels will be
compared to the reference group (i.e. control group). If ref.group =
"all", pairwise two sample tests are performed for comparing each grouping
variable level against all (i.e. basemean).
- p.adjust.method
method to adjust p values for multiple comparisons. Used
when pairwise comparisons are performed. Allowed values include "holm",
"hochberg", "hommel", "bonferroni", "BH", "BY", "fdr", "none". If you don't
want to adjust the p value (not recommended), use p.adjust.method = "none".
- alternative
indicates the alternative hypothesis and must be
one of "two.sided" (default), "less", or
"greater". You can specify just the initial letter of the
value, but the argument name must be given in full.
See ‘Details’ for the meanings of the possible values.
- exact
NULL or a logical indicating whether an exact
p-value should be computed. See ‘Details’ for the meaning of
NULL.
- detailed
logical value. Default is FALSE. If TRUE, a detailed result is
shown.